@@ -106,7 +106,14 @@ macro_block_size: int
     automatic feature set it to None or 1, however be warned many players
     can't decode videos that are odd in size and some codecs will produce
     poor results or fail. See https://en.wikipedia.org/wiki/Macroblock.
-
+audio_path : str | None
+    Audio path of any audio that needs to be written. Defaults to nothing,
+    so no audio will be written. Please note, when writing shorter video
+    than the original, ffmpeg will not truncate the audio track; it
+    will maintain its original length and be longer than the video.
+audio_codec : str | None
+    The audio codec to use. Defaults to nothing, but if an audio_path has
+    been provided ffmpeg will attempt to set a default codec.
 
 Notes
 -----
@@ -321,20 +328,23 @@ class FfmpegFormat(Format):
             # metadata when we boot ffmpeg ... maybe we could refactor this so we can
             # get the metadata beforehand, but for now we'll just give it 2 tries on MacOS,
             # one with fps 30 and one with fps 15.
-            need_fps = (
-                self.request._video
-                and platform.system().lower() == "darwin"
-                and "-framerate" not in str(self._arg_input_params)
-            )
-            if need_fps:
+            need_input_fps = need_output_fps = False
+            if self.request._video and platform.system().lower() == "darwin":
+                if "-framerate" not in str(self._arg_input_params):
+                    need_input_fps = True
+                if not self.request.kwargs.get("fps", None):
+                    need_output_fps = True
+            if need_input_fps:
                 self._arg_input_params.extend(["-framerate", str(float(30))])
+            if need_output_fps:
+                self._arg_output_params.extend(["-r", str(float(30))])
 
             # Start ffmpeg subprocess and get meta information
             try:
                 self._initialize()
             except IndexError:
                 # Specify input framerate again, this time different.
-                if need_fps:
+                if need_input_fps:
                     self._arg_input_params[-1] = str(float(15))
                     self._initialize()
                 else:
@@ -539,6 +549,8 @@ class FfmpegFormat(Format):
             ffmpeg_log_level="quiet",
             quality=5,
             macro_block_size=16,
+            audio_path=None,
+            audio_codec=None,
         ):
             self._ffmpeg_api = imageio_ffmpeg
             self._filename = self.request.get_local_filename()
@@ -614,6 +626,8 @@ class FfmpegFormat(Format):
             pixelformat = self.request.kwargs.get("pixelformat", None)
             macro_block_size = self.request.kwargs.get("macro_block_size", 16)
             ffmpeg_log_level = self.request.kwargs.get("ffmpeg_log_level", None)
+            audio_path = self.request.kwargs.get("audio_path", None)
+            audio_codec = self.request.kwargs.get("audio_codec", None)
 
             macro_block_size = macro_block_size or 1  # None -> 1
 
@@ -631,6 +645,8 @@ class FfmpegFormat(Format):
                 ffmpeg_log_level=ffmpeg_log_level,
                 input_params=input_params,
                 output_params=output_params,
+                audio_path=audio_path,
+                audio_codec=audio_codec,
             )
 
             # Seed the generator (this is where the ffmpeg subprocess starts)
