@@ -7,7 +7,6 @@
 import logging
 import numpy as np
 
-from .. import formats
 from ..core import Format, image_as_uint
 from ._freeimage import fi, IO_FLAGS
 from .freeimage import FreeimageFormat
@@ -290,9 +289,6 @@ class GifFormat(FreeimageMulti):
             # Quantize it if its RGB
             if im.ndim == 3 and im.shape[-1] == 3:
                 sub2 = sub1.quantize(self._quantizer, self._palettesize)
-            # If single image, omit animation data
-            if self.request.mode[1] == "i":
-                del meta["ANIMATION"]
             # Set meta data and return
             sub2.set_meta_data(meta)
             return sub2
@@ -319,11 +315,3 @@ class GifFormat(FreeimageMulti):
                 y0, y1 = 0, 2
             # Cut out and return
             return im[y0:y1, x0:x1], (x0, y0)
-
-
-# formats.add_format(MngFormat('MNG', 'Multiple network graphics',
-#                                    '.mng', 'iI'))
-formats.add_format(IcoFormat("ICO-FI", "Windows icon", ".ico", "iI"))
-formats.add_format(
-    GifFormat("GIF-FI", "Static and animated gif (FreeImage)", ".gif", "iI")
-)
