@@ -1,6 +1,7 @@
 import gc
 import shutil
 from pathlib import Path
+import sys
 from typing import List
 
 import imageio
@@ -236,13 +237,11 @@ def test_default_can_read_and_can_write(tmp_path):
     assert F.can_read(Request(filename1 + ".foo", "rv"))
     assert F.can_read(Request(filename1 + ".bar", "r?"))
     assert not F.can_read(Request(filename1 + ".spam", "r?"))
-    assert not F.can_read(Request(filename1 + ".foo", "ri"))
 
     # Test _can_write()
     assert F.can_write(Request(filename1 + ".foo", "wv"))
     assert F.can_write(Request(filename1 + ".bar", "w?"))
     assert not F.can_write(Request(filename1 + ".spam", "w?"))
-    assert not F.can_write(Request(filename1 + ".foo", "wi"))
 
 
 @deprecated_test
@@ -437,3 +436,24 @@ def test_write_format_search_fail(tmp_path):
 @deprecated_test
 def test_format_by_filename():
     iio.formats["test.jpg"]
+
+
+@pytest.fixture()
+def missing_ffmpeg():
+    old_ffmpeg = sys.modules.get("imageio_ffmpeg")
+    old_plugin = sys.modules.get("imageio.plugins.ffmpeg")
+    sys.modules["imageio_ffmpeg"] = None
+    sys.modules.pop("imageio.plugins.ffmpeg")
+
+    yield
+
+    sys.modules["imageio_ffmpeg"] = old_ffmpeg
+    sys.modules["imageio.plugins.ffmpeg"] = old_plugin
+
+
+def test_missing_format(missing_ffmpeg):
+    # regression test for
+    # https://github.com/imageio/imageio/issues/887
+
+    for format in imageio.formats:
+        assert format.name != "FFMPEG"
